==> SugarCE-6.4.6.zip: SugarCE-Full-6.4.6/modules/Meetings/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD' => 'A record number must be specified to delete the meeting.',

	'LBL_ACCEPT_THIS'=>'Accept?',
	'LBL_ADD_BUTTON'=> 'Add',
	'LBL_ADD_INVITEE' => 'Add Invitees',
	'LBL_COLON' => ':',
	'LBL_CONTACT_NAME' => 'Contact:',
	'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
	'LBL_CREATED_BY'=>'Created by',
	'LBL_DATE_END'=>'Date End',
	'LBL_DATE_TIME' => 'Start Date & Time:',
	'LBL_DATE' => 'Start Date:',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Meetings',
	'LBL_DEL'=> 'Del',
	'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
	'LBL_DESCRIPTION' => 'Description:',
	'LBL_DURATION_HOURS' => 'Duration Hours:',
	'LBL_DURATION_MINUTES' => 'Duration Minutes:',
	'LBL_DURATION' => 'Duration:',
	'LBL_EMAIL' => 'Email',
	'LBL_FIRST_NAME' => 'First Name',
	'LBL_HISTORY_SUBPANEL_TITLE' => 'Notes',
	'LBL_HOURS_ABBREV' => 'h',
	'LBL_HOURS_MINS' => '(hours/minutes)',
	'LBL_INVITEE' => 'Invitees',
	'LBL_LAST_NAME' => 'Last Name',
	'LBL_ASSIGNED_TO_NAME'=>'Assigned to:',
	'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned User',
	'LBL_LIST_CLOSE' => 'Close',
	'LBL_LIST_CONTACT' => 'Contact',
	'LBL_LIST_DATE_MODIFIED'=>'Date Modified',
	'LBL_LIST_DATE' => 'Start Date',
	'LBL_LIST_DIRECTION' => 'Direction',
	'LBL_LIST_DUE_DATE'=>'Due Date',
	'LBL_LIST_FORM_TITLE' => 'Meeting List',
	'LBL_LIST_MY_MEETINGS' => 'My Meetings',
	'LBL_LIST_RELATED_TO' => 'Related to',
	'LBL_LIST_STATUS'=>'Status',
	'LBL_LIST_SUBJECT' => 'Subject',
	'LBL_LIST_TIME' => 'Start Time',
	'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
	'LBL_LOCATION' => 'Location:',
	'LBL_MEETING' => 'Meeting:',
	'LBL_MINSS_ABBREV' => 'm',
	'LBL_MODIFIED_BY'=>'Modified by',
	'LBL_MODULE_NAME' => 'Meetings',
	'LBL_MODULE_TITLE' => 'Meetings: Home',
	'LBL_NAME' => 'Name',
	'LBL_NEW_FORM_TITLE' => 'Create Appointment',
	'LBL_OUTLOOK_ID' => 'Outlook ID',
	'LBL_SEQUENCE' => 'Meeting update sequence',
	'LBL_PHONE' => 'Phone Office:',
	'LBL_REMINDER_TIME'=>'Reminder Time',
	'LBL_REMINDER' => 'Reminder:',
    'LBL_REMOVE' => 'rem',
	'LBL_SCHEDULING_FORM_TITLE' => 'Scheduling',
	'LBL_SEARCH_BUTTON'=> 'Search',
	'LBL_SEARCH_FORM_TITLE' => 'Meeting Search',
	'LBL_SEND_BUTTON_KEY'=>'I',
	'LBL_SEND_BUTTON_LABEL'=>'Send Invites',
	'LBL_SEND_BUTTON_TITLE'=>'Send Invites',
	'LBL_STATUS' => 'Status:',
    'LBL_TYPE' => 'Meeting Type',
    'LBL_PASSWORD' => 'Meeting Password',
    'LBL_URL' => 'Start/Join Meeting',
    'LBL_HOST_URL' => 'Host URL',
    'LBL_DISPLAYED_URL' => 'Display URL',
   'LBL_CREATOR' => 'Meeting Creator',
   'LBL_EXTERNALID' => 'External App ID',
	'LBL_SUBJECT' => 'Subject:',
	'LBL_TIME' => 'Start Time:',
	'LBL_USERS_SUBPANEL_TITLE' => 'Users',
	'LBL_ACTIVITIES_REPORTS' => 'Activities Report',
    'LBL_PARENT_TYPE' => 'Parent Type',
    'LBL_PARENT_ID' => 'Parent ID',
	'LNK_MEETING_LIST'=>'View Meetings',
	'LNK_NEW_APPOINTMENT' => 'Create Appointment',
	'LNK_NEW_MEETING'=>'Schedule Meeting',
	'LNK_IMPORT_MEETINGS' => 'Import Meetings',

	'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
    'LBL_CREATED_USER' => 'Created User',
    'LBL_MODIFIED_USER' => 'Modified User',
    'NOTICE_DURATION_TIME' => 'Duration time must be greater than 0',
    'LBL_MEETING_INFORMATION' => 'Overview',
	'LBL_LIST_JOIN_MEETING' => 'Join Meeting',
	'LBL_JOIN_EXT_MEETING' => 'Join Meeting',
	'LBL_HOST_EXT_MEETING' => 'Start Meeting',
    'LBL_ACCEPT_STATUS' => 'Accept Status',
    'LBL_ACCEPT_LINK' => 'Accept Link',
    // You are not invited to the meeting messages
    'LBL_EXTNOT_HEADER' => 'Error: Not Invited',
    'LBL_EXTNOT_MAIN' => 'You are not able to join this meeting because you are not an Invitee.',
    'LBL_EXTNOT_RECORD_LINK' => 'View Meeting',
    'LBL_EXTNOT_GO_BACK' => 'Go back to the previous record',

    //cannot start messages
    'LBL_EXTNOSTART_HEADER' => 'Error: Cannot Start Meeting',
    'LBL_EXTNOSTART_MAIN' => 'You cannot start this meeting because you are not an Administrator or the owner of the meeting.',

  //For export labels
    'LBL_EXPORT_JOIN_URL' => 'Join Url',
    'LBL_EXPORT_HOST_URL' => 'Host Url',
    'LBL_EXPORT_DISPLAYED_URL' => 'Displayed Url',
    'LBL_EXPORT_ASSIGNED_USER_ID' => 'Assigned User ID',
    'LBL_EXPORT_EXTERNAL_ID' => 'External ID',
    'LBL_EXPORT_ASSIGNED_USER_NAME' => 'Assigned User Name',
    'LBL_EXPORT_MODIFIED_USER_ID' => 'Modified By ID',
    'LBL_EXPORT_CREATED_BY' => 'Created By ID',

    'LBL_EXPORT_DATE_START' => 'Start Date and Time',
    'LBL_EXPORT_DATE_END' => 'End Date and Time',
    'LBL_EXPORT_PARENT_TYPE' => 'Related Type',
    'LBL_EXPORT_PARENT_ID' => 'Parent ID',
    'LBL_EXPORT_REMINDER_TIME' =>'Reminder Time (in minutes)',
);
?>

==> SugarCE-6.5.6.zip: SugarCE-Full-6.5.6/modules/Meetings/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'ERR_DELETE_RECORD' => 'A record number must be specified to delete the meeting.',

	'LBL_ACCEPT_THIS'=>'Accept?',
	'LBL_ADD_BUTTON'=> 'Add',
	'LBL_ADD_INVITEE' => 'Add Invitees',
	'LBL_ADD_PARENT_INVITEE' => 'Add Related person to invitees',
	'LBL_COLON' => ':',
	'LBL_CONTACT_NAME' => 'Contact:',
	'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
	'LBL_CREATED_BY'=>'Created by',
	'LBL_DATE_END'=>'End Date',
	'LBL_DATE_TIME' => 'Start Date & Time:',
	'LBL_DATE' => 'Start Date:',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Meetings',
	'LBL_DEL'=> 'Del',
	'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
	'LBL_DESCRIPTION' => 'Description:',
    'LBL_DIRECTION' => 'Direction:',
	'LBL_DURATION_HOURS' => 'Duration Hours:',
	'LBL_DURATION_MINUTES' => 'Duration Minutes:',
	'LBL_DURATION' => 'Duration:',
	'LBL_EMAIL' => 'Email',
	'LBL_FIRST_NAME' => 'First Name',
	'LBL_HISTORY_SUBPANEL_TITLE' => 'Notes',
	'LBL_HOURS_ABBREV' => 'h',
	'LBL_HOURS_MINS' => '(hours/minutes)',
	'LBL_INVITEE' => 'Invitees',
	'LBL_LAST_NAME' => 'Last Name',
	'LBL_ASSIGNED_TO_NAME'=>'Assigned to:',
	'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned User',
	'LBL_LIST_CLOSE' => 'Close',
	'LBL_LIST_CONTACT' => 'Contact',
	'LBL_LIST_DATE_MODIFIED'=>'Date Modified',
	'LBL_LIST_DATE' => 'Start Date',
	'LBL_LIST_DIRECTION' => 'Direction',
	'LBL_LIST_DUE_DATE'=>'Due Date',
	'LBL_LIST_FORM_TITLE' => 'Meeting List',
	'LBL_LIST_MY_MEETINGS' => 'My Meetings',
	'LBL_LIST_RELATED_TO' => 'Related to',
	'LBL_LIST_STATUS'=>'Status',
	'LBL_LIST_SUBJECT' => 'Subject',
	'LBL_LIST_TIME' => 'Start Time',
	'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
	'LBL_LOCATION' => 'Location:',
	'LBL_MEETING' => 'Meeting:',
	'LBL_MINSS_ABBREV' => 'm',
	'LBL_MODIFIED_BY'=>'Modified by',
	'LBL_MODULE_NAME' => 'Meetings',
	'LBL_MODULE_TITLE' => 'Meetings: Home',
	'LBL_NAME' => 'Name',
	'LBL_NEW_FORM_TITLE' => 'Create Appointment',
	'LBL_OUTLOOK_ID' => 'Outlook ID',
	'LBL_SEQUENCE' => 'Meeting update sequence',
	'LBL_PHONE' => 'Phone Office:',
	'LBL_REMINDER_TIME'=>'Reminder Time',
    'LBL_EMAIL_REMINDER_SENT' => 'Email reminder sent',
	'LBL_REMINDER' => 'Reminders:',
	'LBL_REMINDER_POPUP' => 'Popup',
	'LBL_REMINDER_EMAIL' => 'Email',
    'LBL_REMINDER_EMAIL_ALL_INVITEES' => 'Email all invitees',
    'LBL_EMAIL_REMINDER' => 'Email Reminder',
    'LBL_EMAIL_REMINDER_TIME' => 'Email Reminder Time',
    'LBL_REMOVE' => 'rem',
	'LBL_SCHEDULING_FORM_TITLE' => 'Scheduling',
	'LBL_SEARCH_BUTTON'=> 'Search',
	'LBL_SEARCH_FORM_TITLE' => 'Meeting Search',
	'LBL_SEND_BUTTON_KEY'=>'I',
	'LBL_SEND_BUTTON_LABEL'=>'Save & Send Invites',
	'LBL_SEND_BUTTON_TITLE'=>'Save & Send Invites',
	'LBL_STATUS' => 'Status:',
    'LBL_TYPE' => 'Meeting Type',
    'LBL_PASSWORD' => 'Meeting Password',
    'LBL_URL' => 'Start/Join Meeting',
    'LBL_HOST_URL' => 'Host URL',
    'LBL_DISPLAYED_URL' => 'Display URL',
    'LBL_CREATOR' => 'Meeting Creator',
    'LBL_EXTERNALID' => 'External App ID',
	'LBL_SUBJECT' => 'Subject:',
	'LBL_TIME' => 'Start Time:',
	'LBL_USERS_SUBPANEL_TITLE' => 'Users',
	'LBL_ACTIVITIES_REPORTS' => 'Activities Report',
    'LBL_PARENT_TYPE' => 'Parent Type',
    'LBL_PARENT_ID' => 'Parent ID',
	'LNK_MEETING_LIST'=>'View Meetings',
	'LNK_NEW_APPOINTMENT' => 'Create Appointment',
	'LNK_NEW_MEETING'=>'Schedule Meeting',
	'LNK_IMPORT_MEETINGS' => 'Import Meetings',

	'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
    'LBL_CREATED_USER' => 'Created User',
    'LBL_MODIFIED_USER' => 'Modified User',
    'NOTICE_DURATION_TIME' => 'Duration time must be greater than 0',
    'LBL_MEETING_INFORMATION' => 'Overview',
	'LBL_LIST_JOIN_MEETING' => 'Join Meeting',
	'LBL_JOIN_EXT_MEETING' => 'Join Meeting',
	'LBL_HOST_EXT_MEETING' => 'Start Meeting',
    'LBL_ACCEPT_STATUS' => 'Accept Status',
    'LBL_ACCEPT_LINK' => 'Accept Link',
    // You are not invited to the meeting messages
    'LBL_EXTNOT_HEADER' => 'Error: Not Invited',
    'LBL_EXTNOT_MAIN' => 'You are not able to join this meeting because you are not an Invitee.',
    'LBL_EXTNOT_RECORD_LINK' => 'View Meeting',
    'LBL_EXTNOT_GO_BACK' => 'Go back to the previous record',

    //cannot start messages
    'LBL_EXTNOSTART_HEADER' => 'Error: Cannot Start Meeting',
    'LBL_EXTNOSTART_MAIN' => 'You cannot start this meeting because you are not an Administrator or the owner of the meeting.',

  //For export labels
    'LBL_EXPORT_JOIN_URL' => 'Join Url',
    'LBL_EXPORT_HOST_URL' => 'Host Url',
    'LBL_EXPORT_DISPLAYED_URL' => 'Displayed Url',
    'LBL_EXPORT_ASSIGNED_USER_ID' => 'Assigned User ID',
    'LBL_EXPORT_EXTERNAL_ID' => 'External ID',
    'LBL_EXPORT_ASSIGNED_USER_NAME' => 'Assigned User Name',
    'LBL_EXPORT_MODIFIED_USER_ID' => 'Modified By ID',
    'LBL_EXPORT_CREATED_BY' => 'Created By ID',

    'LBL_EXPORT_DATE_START' => 'Start Date and Time',
    'LBL_EXPORT_DATE_END' => 'End Date and Time',
    'LBL_EXPORT_PARENT_TYPE' => 'Related Type',
    'LBL_EXPORT_PARENT_ID' => 'Parent ID',
    'LBL_EXPORT_REMINDER_TIME' =>'Reminder Time (in minutes)',

    // create invitee functionallity
    'LBL_CREATE_INVITEE' => 'Create an invitee',
    'LBL_CREATE_CONTACT' => 'As Contact',
    'LBL_CREATE_LEAD' => 'As Lead',
    'LBL_CREATE_AND_ADD' => 'Create & Add',
    'LBL_CANCEL_CREATE_INVITEE' => 'Cancel',
    'LBL_EMPTY_SEARCH_RESULT' => 'Sorry, no results were found. Please create an invitee below.',
    'LBL_NO_ACCESS' => 'You have no access to create $module',
    
    'LBL_REPEAT_TYPE' => 'Repeat Type',
    'LBL_REPEAT_INTERVAL' => 'Repeat Interval',
    'LBL_REPEAT_DOW' => 'Repeat Dow',
    'LBL_REPEAT_UNTIL' => 'Repeat Until',
    'LBL_REPEAT_COUNT' => 'Repeat Count',
    'LBL_REPEAT_PARENT_ID' => 'Repeat Parent ID',
    'LBL_RECURRING_SOURCE' => 'Recurring Source',
    
    'LBL_SYNCED_RECURRING_MSG' => 'This meeting originated in another system and was synced to Sugar. To make changes, go to the original meeting within the other system. Changes made in the other system can be synced to this record.',
    'LBL_RELATED_TO' => 'Related to:',
);
?>
